package com.ruoyi.project.mapper;

import java.util.Date;
import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.annotation.InterceptorIgnore;
import com.ruoyi.project.domain.TrsSiteconfig;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * 配置管理Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-19
 */
@Mapper
//@InterceptorIgnore(tenantLine = "true")
public interface TrsSiteconfigMapper 
{
    /**
     * 查询配置管理
     * 
     * @param id 配置管理主键
     * @return 配置管理
     */
    public TrsSiteconfig selectTrsSiteconfigById(Long id);

    @InterceptorIgnore(tenantLine = "true")
    public TrsSiteconfig selectTrsSiteconfigById2(Long id);

    /**
     * 查询配置管理列表
     * 
     * @param trsSiteconfig 配置管理
     * @return 配置管理集合
     */
    public List<TrsSiteconfig> selectTrsSiteconfigList(TrsSiteconfig trsSiteconfig);

    @InterceptorIgnore(tenantLine = "true")
    public List<TrsSiteconfig> selectTrsSiteconfigList2(TrsSiteconfig trsSiteconfig);

    /**
     * 新增配置管理
     * 
     * @param trsSiteconfig 配置管理
     * @return 结果
     */
    public int insertTrsSiteconfig(TrsSiteconfig trsSiteconfig);

    /**
     * 修改配置管理
     * 
     * @param trsSiteconfig 配置管理
     * @return 结果
     */
    public int updateTrsSiteconfig(TrsSiteconfig trsSiteconfig);

    /**
     * 删除配置管理
     * 
     * @param id 配置管理主键
     * @return 结果
     */
    public int deleteTrsSiteconfigById(Long id);

    /**
     * 批量删除配置管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTrsSiteconfigByIds(String[] ids);

    Integer getTotalTexts(@Param("sitename") String sitename, @Param("startDate") Date startDate, @Param("endDate") Date endDate);
    Integer getProblemTexts(@Param("sitename") String sitename, @Param("startDate") Date startDate, @Param("endDate") Date endDate);
    List<Map<String, Object>> getHighFrequencyErrors(@Param("sitename") String sitename, @Param("startDate") Date startDate, @Param("endDate") Date endDate, @Param("limit") int limit);

    Integer countByStatus(@Param("status") String status, @Param("sitename") String sitename, @Param("startDate") Date startDate, @Param("endDate") Date endDate);

    Object countByType(@Param("errorType") String errorType,@Param("sitename")  String sitename,@Param("startDate")  Date startDate,@Param("endDate")  Date endDate);
}
